@@ -10,7 +10,7 @@ logging.basicConfig(level=logging.INFO)
 # Change from -1 to 0 to enable GPU
 os.environ['CUDA_VISIBLE_DEVICES'] = "-1"
 
-infercode = InferCodeClient(language="cpp")
+infercode = InferCodeClient(language="c")
 infercode.init_from_config()
 vectors = infercode.encode(["for (i = 0; i < n; i++)", "struct book{ int num; char s[27]; }shu[1000];"])
 
